@@ -8,6 +8,7 @@ from __future__ import print_function
 
 import json
 import sys
+from optparse import OptionParser
 
 import json_tools
 from print_style import colorize
@@ -25,18 +26,37 @@ def usage():
 
 
 def pretty_print():
+    parser = OptionParser()
+    parser.add_option("-c", "--color", dest="colors", action="store_true",
+                      help="Colorize the output", default=False)
+    options, files = parser.parse_args()
+    file_name = files[0] if files else '/dev/stdin'
+
     try:
-        with open(sys.argv[2]) as f:
-            data = json.load(f)
-    except IOError:
-        print('File not found', file=sys.stderr)
+        f = open(file_name)
+    except:
+        print("Could not open input file", file=sys.stderr)
         exit(-1)
-    json_tools.print_json(data, '--pretty' in sys.argv)
+
+    try:
+        data = json.load(f)
+    except IOError:
+        print("Could not decode JSON from the input file", file=sys.stderr)
+        exit(-1)
+    json_tools.print_json(data, options.colors)
 
 
 def diff():
+    parser = OptionParser()
+    parser.add_option("-c", "--color", dest="colors", action="store_true",
+                      help="Colorize the output", default=False)
+    options, files = parser.parse_args()
+    if len(files) < 2:
+        print("Need at least 2 JSON files", file=sys.stderr)
+        exit(-1)
+
     try:
-        with open(sys.argv[2]) as f:
+        with open(files[0]) as f:
             local = json.load(f)
     except IOError:
         print('Local not found', file=sys.stderr)
@@ -46,7 +66,7 @@ def diff():
         exit(-1)
 
     try:
-        with open(sys.argv[3]) as f:
+        with open(files[1]) as f:
             other = json.load(f)
     except IOError:
         print('Other not found', file=sys.stderr)
@@ -56,32 +76,45 @@ def diff():
         exit(-1)
 
     res = json_tools.diff(local, other)
-    json_tools.print_json(res, '--pretty' in sys.argv)
+    json_tools.print_json(res, options.colors)
 
 
 def patch():
+    parser = OptionParser()
+    parser.add_option("-c", "--color", dest="colors", action="store_true",
+                      help="Colorize the output", default=False)
+    options, files = parser.parse_args()
+    if len(files) == 1:
+        source = '/dev/stdin'
+        patch = files[0]
+    elif len(files) >= 2:
+        source, patch = files[0:2]
+    else:
+        print("Need at least 1 JSON files", file=sys.stderr)
+        exit(-1)
+
     try:
-        with open(sys.argv[2]) as f:
+        with open(source) as f:
             data = json.load(f)
     except IOError:
-        print('Local not found', file=sys.stderr)
+        print('Source file not found', file=sys.stderr)
         exit(-1)
     except KeyError:
         print('Path to file not specified', file=sys.stderr)
         exit(-1)
 
     try:
-        with open(sys.argv[3]) as f:
+        with open(patch) as f:
             patch = json.load(f)
     except IOError:
-        print('Other not found', file=sys.stderr)
+        print('Patch not found', file=sys.stderr)
         exit(-1)
     except KeyError:
         print('Path to other file not specified', file=sys.stderr)
         exit(-1)
 
     res = json_tools.patch(data, patch)
-    json_tools.print_json(res, '--pretty' in sys.argv)
+    json_tools.print_json(res, options.colors)
 
 
 COMMANDS = {
@@ -92,14 +125,17 @@ COMMANDS = {
 
 
 def main():
-    if len(sys.argv) < 3:
+    if len(sys.argv) < 2:
         usage()
         exit(-1)
     else:
+        cmd = sys.argv[1]
+        sys.argv = sys.argv[1:]
         try:
-            COMMANDS[sys.argv[1]]()
+            COMMANDS[cmd]()
         except KeyError:
-            print('Bad command:', sys.argv[1], file=sys.stderr)
+            print('Bad command:', cmd, file=sys.stderr)
+            exit(-1)
 
 
 if __name__ == '__main__':
